import { HEADER_MENU } from '~/menu'
import logo from '/logo.svg'
import arrowRight from '~/components/icons/arrow-right-white.svg'
import { NavLink, useLocation } from 'react-router'
import Button from '~/components/items/button'
import UserDropdown from '~/components/items/user-dropdown'
import userIcon from '~/components/icons/user.svg'
import signOutIcon from '~/components/icons/signout.svg'
import xMark from '~/images/xmark.svg'
import { useState } from 'react'
import menuIcon from '~/images/menu.svg'
import { ROUTES } from '~/routes'

export default function Header() {
  const [isOpen, setIsOpen] = useState(false)
  const location = useLocation()
  const path = location.pathname

  const dropdownList = [
    {
      iconUrl: userIcon,
      label: 'Giriş Yap',
      url: '/auth/login'
    },
    {
      iconUrl: signOutIcon,
      label: 'Çıkış Yap',
      url: '/auth/signout'
    }
  ]

  const transparentBg = [ROUTES.HOME, ROUTES.SERVICES, ROUTES.NEWS + '/']

  return (
    <header className={`${transparentBg.some(s => s.includes('news') ? true : s === path) ? '' : 'bg-white'} relative z-50`}>
      <div className="container mx-auto px-4">
        <div className={`${transparentBg.some(s => s.includes('news') ? true : s === path) ? 'border-b border-gray/10' : ''} flex justify-between items-center py-2 sm:py-4 sm:h-[102px]`}>
          <NavLink to="/">
            <img src={logo} alt="" />
          </NavLink>
          <nav
            className={
              'transition-all lg:relative lg:right-0! fixed top-0 w-full bottom-0 bg-white lg:bg-transparent lg:top-auto lg:left-auto lg:bottom-auto lg:flex lg:items-center lg:justify-end lg:h-auto lg:space-x-5 lg:py-0 py-4 px-4 lg:px-0'
            }
            style={{ right: isOpen ? 0 : '-150%' }}
          >
            <span
              className="absolute right-5 top-5 lg:hidden cursor-pointer"
              onClick={() => setIsOpen(!isOpen)}
            >
              <img src={xMark} width={24} height={24} alt="" />
            </span>
            <ul className="lg:space-y-0 space-y-4 lg:flex xl:space-x-5 space-x-3 items-center">
              {HEADER_MENU.map((menu, i) => (
                <li key={i} className="font-medium lg:text-sm xl:text-base">
                  <NavLink to={menu.url}>{menu.label}</NavLink>
                </li>
              ))}
              <li>
                <NavLink to="/">
                  <Button iconUrl={arrowRight}>Markalarımız</Button>
                </NavLink>
              </li>
              <li className="hidden lg:block">
                <UserDropdown name="Üyelik" list={dropdownList} />
              </li>
              {dropdownList.map((item, i) => (
                <li className="lg:hidden" key={i}>
                  <NavLink to={item.url} className="inline-flex gap-3 items-center">
                    <img src={item.iconUrl} alt="" /> <span className="pb-1">{item.label}</span>
                  </NavLink>
                </li>
              ))}
            </ul>
          </nav>
          <span className="lg:hidden cursor-pointer" onClick={() => setIsOpen(!isOpen)}>
            <img src={menuIcon} width={24} height={24} alt="" />
          </span>
        </div>
      </div>
    </header>
  )
}
